#!/usr/bin/env python3
from stepup.core.api import runsh
from stepup.reprep.api import convert_markdown

for i in range(20):
    fn_random = f"random_{i:02d}.md"
    runsh(f"./write.py {i} > {fn_random}", out=fn_random)
    convert_markdown(fn_random)



#!/usr/bin/env python3
import random
import sys

TEXT_SNIPPETS = [
    "Lorem",
    "ipsum",
    "dolor",
    "sit",
    "amet,",
    "consectetur",
    "adipiscing",
    "elit,",
    "sed",
    "do",
    "eiusmod",
    "tempor",
    "incididunt",
    "ut",
    "labore",
    "et",
    "dolore",
    "magna",
    "aliqua.",
    "Ut",
    "enim",
    "ad",
    "minim",
    "veniam,",
    "quis",
    "nostrud",
    "exercitation",
    "ullamco",
    "laboris",
    "nisi",
    "ut",
    "aliquip",
    "ex",
    "ea",
    "commodo",
    "consequat.",
]


def main():
    """Write a randomized markdown file."""
    random.seed(int(sys.argv[1]))
    print(" ".join(random.choice(TEXT_SNIPPETS) for _ in range(100)))


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
from stepup.core.api import runsh, static
from stepup.reprep.api import make_inventory, zip_inventory

static("static.txt")
runsh("echo hello > ${out}", out="built.txt")
make_inventory("static.txt", "built.txt", "inventory.txt")
zip_inventory("inventory.txt", "upload.zip")



#!/usr/bin/env python3
from stepup.core.api import static
from stepup.reprep.api import convert_markdown

static("sub/", "sub/demo.md", "sub/demo.css", "page.css")
convert_markdown("sub/demo.md", paths_css="page.css")



#!/usr/bin/env python3
from stepup.core.api import glob
from stepup.reprep.api import make_inventory, zip_inventory

# Make all subdirectories in `data` static when they are needed.
glob("data/**/", _defer=True)

# Make all .out files in data static with a recursive glob.
# Containing directories and their parents also become static due to the deferred glob.
out_files = glob("data/**/*.out")

# Create an inventory file with all .out files and zip it.
make_inventory(*out_files, "inventory.txt")
zip_inventory("inventory.txt", "upload.zip")



#!/usr/bin/env python3

from stepup.core.api import static
from stepup.reprep.api import check_hrefs, compile_latex

static("README.txt", "main.tex", "check_hrefs.yaml")
compile_latex("main.tex", inventory=True)
check_hrefs("main.pdf")



#!/usr/bin/env python3

from stepup.core.api import runsh, static
from stepup.reprep.api import compile_latex

static("paper.tex")
static("smile.pdf")
compile_latex("paper.tex")
runsh("echo 'Hi there!' > generated.tex", out=["generated.tex"])



#!/usr/bin/env python3

from stepup.core.api import static
from stepup.reprep.api import compile_latex, sanitize_bibtex

static("paper.tex")
static("bibsane.yaml")
static("references.bib")
compile_latex("${LATEX_MAIN}.tex", inventory=True)
sanitize_bibtex("references.bib", path_aux="${LATEX_MAIN}.aux", path_cfg="bibsane.yaml")



#!/usr/bin/env python3
from stepup.core.api import glob, script, static
from stepup.reprep.api import convert_inkscape_pdf

for path_svg in glob("*.svg"):
    convert_inkscape_pdf(path_svg)
static("tile.py", "vera.ttf")
script("tile.py")



#!/usr/bin/env python3
from stepup.core.api import copy, mkdir, static
from stepup.reprep.latex_deps import scan_latex_deps

static("doc.tex", "snippet.tex", "first.dat", "second.dat")
inp, bib, out, vol = scan_latex_deps("doc.tex")
mkdir("dest/")
for path in inp:
    copy(path, "dest/")



# StepUp RepRep is the StepUp extension for Reproducible Reporting.
# © 2024–2025 Toon Verstraelen
#
# This file is part of StepUp RepRep.
#
# StepUp RepRep is free software;  you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# StepUp RepRep is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --
"""Unit tests for stepup.reprep.latex_deps"""

from stepup.reprep.latex_deps import scan_latex_deps

SCAN_LATEX_DEPS_EXAMPLE = r"""
%REPREP vol volatile.txt
\input{foo.tex}
%\includegraphics{not.pdf}
\includegraphics{figure}
\includegraphics{\thepage.png} %REPREP ignore
\includegraphics
{plot.pdf}
\input{
    % comments before
    results/info.tex
    % comments after
}
\input  {
    % comment 1
    this
    % comment 2 }
    also
    % comment 3 {
    works % comment 4
    % comment 5 }
}
%REPREP inp implicit.txt
%\input{bar.tex}
\bibliography {references}
%\bibliography{old}
\bibliography {
    extra}
\import  {sub  % poor formatting
}    {inc.tex
}
\includepdf[pages=-]{somepages.pdf}
%import{sub}{ex.tex}
%REPREP out sideffect.txt
"""


def test_scan_latex_deps(monkeypatch, path_tmp):
    monkeypatch.chdir(path_tmp)
    with open("main.tex", "w") as fh:
        fh.write(SCAN_LATEX_DEPS_EXAMPLE)
    inp, bib, out, vol = scan_latex_deps("main.tex", "./", do_amend=False)
    inp_ref = {
        "foo.tex",
        "results/info.tex",
        "this also works.tex",
        "figure.pdf",
        "plot.pdf",
        "implicit.txt",
        "sub/inc.tex",
        "somepages.pdf",
    }
    assert set(inp) == inp_ref
    bib_ref = {"references.bib", "extra.bib"}
    assert set(bib) == bib_ref
    assert out == ["sideffect.txt"]
    assert vol == ["volatile.txt"]



#!/usr/bin/env python3
from stepup.core.api import static
from stepup.reprep.api import execute_papermill

static("demo.ipynb", "data.json", "points.txt")
execute_papermill(
    "demo.ipynb", "demo_out.ipynb", inp="points.txt", out="plot.png", parameters={"dpi": 50}
)



#!/usr/bin/env python3
from stepup.core.api import runsh, static
from stepup.reprep.api import compile_typst

static("image.py", "document.typ")
compile_typst("document.typ")
runsh("./image.py", out="image.jpg")



#!/usr/bin/env python3

from stepup.core.api import static
from stepup.reprep.api import compile_latex

static("paper.tex")
static("paper.bbl")
compile_latex("paper.tex", run_bibtex=False, inventory=True)
